#include "SI7021.h"

static I2C_TransferSeq_TypeDef seq;
static I2C_TransferReturn_TypeDef ret;
static uint8_t dataW[1];
static uint8_t dataR[2];
int8_t 	temp;											// storage for temperature
uint8_t	humi;											// storage for humidity

void SI7021_getData(void)
{
	// configure I2C transactions
	dataW[0] = 0xF5;							// command to measure temp & humi
	seq.addr = SI7021_SLAVE_ADDRESS;			// sensor slave address
	seq.flags = I2C_FLAG_WRITE;
	seq.buf[0].data = dataW;
	seq.buf[0].len = 1;

	// request data measurement
	ret = I2C_TransferInit(I2C1, &seq);
	while (ret == i2cTransferInProgress)
		ret = I2C_Transfer(I2C1);

	// get sensor data
	seq.flags = I2C_FLAG_READ;
	seq.buf[0].data = dataR;
	seq.buf[0].len = 2;							// read 2 bytes of humi
	do {
		ret = I2C_TransferInit(I2C1, &seq);
		while (ret == i2cTransferInProgress)
			ret = I2C_Transfer(I2C1);
	}
	while (ret == i2cTransferNack);				// wait for data ready

	while (ret == i2cTransferInProgress)
		ret = I2C_Transfer(I2C1);
	humi = (((((dataR[0] << 8) + dataR[1])*125 + 0x8000) >> 16)-0);	// compute humi
	if (humi > 99)								// saturate humi value
		humi = 99;

	dataW[0] = 0xE0;							// get temp from the last humi conversion
	seq.flags = I2C_FLAG_WRITE_READ;
	seq.buf[0].data = dataW;
	seq.buf[0].len = 1;							// write 1 byte of command
	seq.buf[1].data = dataR;
	seq.buf[1].len = 2;							// read 2 bytes of temp
	ret = I2C_TransferInit(I2C1, &seq);
	while (ret == i2cTransferInProgress)
		ret = I2C_Transfer(I2C1);
	temp = ((((dataR[0] << 8) + dataR[1])*176 + 0x8000) >> 16) - 47;	// compute temp in Celcius
//	temp = temp*9 / 5 + 32;  // convert to Fahrenheit
}

